/* global BDF,Multi,Overlay */

Multi.Overlay = {};

Multi.Overlay.showAuthentification = function (data) {
    var genId = BDF.generateId();
    Overlay.start({
        header: BDF.Loc.escape("_ warning.multi.authentification_required"),
        content: BDF.render("multi:overlay-authentification", {
            genId: genId,
            login: Multi.defaultLogin
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: "_ submit.session.login"
            }}),
        escapeClose: false,
        clickClose: false,
        showClose: false,
        formAttrs: {
            action: BDF.URL,
            method: "GET"
        },
        ajaxForm: {
            dataType: "json",
            data: {
                json: "ping"
            },
            success: function (data, textStatus, jqXHR, $form) {
                var done = BDF.Ajax.checkError(data);
                if (done) {
                     Overlay.end($form);
                }
            }
        },
        afterEnd: function () {
            if (Multi.waitingProcess) {
                Multi.waitingProcess();
                Multi.waitingProcess = null;
            }
        }
    });
};

Multi.Overlay.showCreationForm = function () {
    var genId = BDF.generateId();
    Overlay.start({
        header: BDF.Loc.escape("_ title.multi.newfichotheque"),
        content: BDF.render("multi:overlay-creationform", {
            genId: genId,
            availableFichothequeArray: _getAvailableFichotheArray()
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: "_ submit.multi.fichothequecreation"
            }}),
        formAttrs: {
            action: BDF.URL,
            method: "POST"
        },
        afterStart: function ($overlayDialog) {
            BDF.Deploy.init($overlayDialog);
            BDF.$($overlayDialog, {_element: "input", _name: "sphereorigin"}).change(function () {
                let required = (this.value === "creation");
                BDF.$($$(genId, "creation_panel"), {_element: "input"}).prop("required", required);
            });
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                if (!data.authentified) {
                    Overlay.end($form, function () {
                        Multi.testAuthentification(data);
                    });
                } else if (BDF.Ajax.checkError(data)) {
                    Overlay.end($form, function () {
                        Multi.List.update(data.fichothequeArray, function () {
                            BDF.showCommandMessage(data.commandMessage);
                        });
                    });
                }
            }
        }
    });
    
    
    function _getAvailableFichotheArray() {
        let result = new Array();
        if (Multi.fichothequeArray) {
            for(let fichotheque of  Multi.fichothequeArray) {
                if (fichotheque.init) {
                    result.push(fichotheque);
                }
            }
        }
        if (result.length === 0) {
            return null;
        } else {
            return result;
        }
    }
    
};

Multi.Overlay.showDuplicationForm = function (fichothequeName) {
    if (!Multi.fichothequeArray) {
        BDF.log("Multi.fichothequeArray is not initialized");
        return;
    }
    var fichotheque;
    var genId = BDF.generateId();
    for(let existing of  Multi.fichothequeArray) {
        if (existing.name === fichothequeName) {
            fichotheque = existing;
            break;
        }
    }
    if ((!fichotheque) || (!fichotheque.init)) {
        return;
    }
    _completeFichotheque();
    Overlay.start({
        header: BDF.Loc.escape("_ title.multi.duplicatefichotheque"),
        content: BDF.render("multi:overlay-duplicationform", {
            source: fichotheque,
            genId: genId
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: "_ submit.multi.fichothequeduplication"
            }}),
        formAttrs: {
            action: BDF.URL,
            method: "POST"
        },
         ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                if (!data.authentified) {
                    Overlay.end($form, function () {
                        Multi.testAuthentification(data)
                    });
                } else if (BDF.Ajax.checkError(data)) {
                    Overlay.end($form, function () {
                        Multi.List.update(data.fichothequeArray, function () {
                            BDF.showCommandMessage(data.commandMessage);
                        });
                    });
                }
            }
        },
        afterStart: function ($overlayDialog) {
            BDF.$($overlayDialog, {_element: "input", _name: "subsets"}).click(function () {
                var id = this.id;
                var $label = BDF.$({_element: "label", _for: id});
                var key = this.value;
                var $block = BDF.$({role: "block-items", key: key});
                if (this.checked) {
                    $label.removeClass("multi-ExcludeSubset").addClass("multi-IncludeSubset");
                    $block.show();
                } else {
                    $label.removeClass("multi-IncludeSubset").addClass("multi-ExcludeSubset");
                    $block.hide();
                }
            });
            BDF.$($overlayDialog, {_element: "input", role: "items"}).click(function () {
                var checked = this.checked;
                var id = this.id;
                var name = this.name;
                BDF.$({_element: "input", _name: name}).each(function (index, element) {
                    let inputId = element.id;
                    if (inputId === id) {
                        BDF.$({_element: "label", _for: inputId}).addClass("multi-Checked");
                    } else {
                        BDF.$({_element: "label", _for: inputId}).removeClass("multi-Checked");
                    }
                });
            });
        }
    });
    
    
    function _completeFichotheque() {
        _completeTree("corpus");
        _completeTree("thesaurus");
        _completeTree("sphere");
        _completeTree("addenda");
        _completeTree("album");
    }
    
    function _completeTree(category) {
        for(let node of fichotheque[category]) {
            __completeNode(node);
        }
        
        function __completeNode(node) {
            if (node.node === "subset") {
                node._category = category;
            } else {
                for(let subnode of node.array) {
                    __completeNode(subnode);
                }
            }
        }
    }
    
};
